﻿using System.Collections.Generic;
using System.Linq;

namespace NUnit.Framework.Tests
{
    [TestFixture]
    public class AssertionTests
    {
        [Test]
        public void can_assert_should_be_sorted_ascending_by_integer()
        {
            Context().ShouldBeSortedAscending(x => x.Id);
        }

        [Test]
        public void can_assert_should_be_sorted_ascending_by_string()
        {
            var list = Context();
            list.OrderBy(x => x.Name).ShouldBeSortedAscending(x => x.Name);
        }

        [Test]
        public void can_assert_should_be_sorted_descending_by_integer()
        {
            var list = Context();
            list.OrderByDescending(x => x.Id).ShouldBeSortedDescending(x => x.Id);
        }

        [Test]
        public void can_assert_should_be_sorted_descending_by_string()
        {
            var list = Context();
            list.OrderByDescending(x => x.Name).ShouldBeSortedDescending(x => x.Name);
        }

        [Test]
        public void fail_when_not_sorted_ascending()
        {
            typeof(AssertionException)
                .ShouldBeThrownBy(
                () =>
                new List<Item>
                    {
                        new Item {Id = 1, Name = null},
                        new Item {Id = 2, Name = null},
                        new Item {Id = 3, Name = "a"},
                        new Item {Id = 4, Name = "b"},
                        new Item {Id = 5, Name = "c"},
                        new Item {Id = 6, Name = "d"},
                        new Item {Id = 7, Name = null},
                        new Item {Id = 8, Name = null},
                    }
                    .ShouldBeSortedAscending(x => x.Name)
                );
        }

        [Test]
        public void fail_when_not_sorted_descending()
        {
            typeof(AssertionException)
                .ShouldBeThrownBy(
                () =>

                new List<Item>
                    {
                        new Item {Id = 1, Name = null},
                        new Item {Id = 2, Name = null},
                        new Item {Id = 3, Name = "a"},
                        new Item {Id = 4, Name = "b"},
                        new Item {Id = 5, Name = "c"},
                        new Item {Id = 6, Name = "d"},
                        new Item {Id = 7, Name = null},
                        new Item {Id = 8, Name = null},
                    }
                    .ShouldBeSortedDescending(x => x.Name)
                );
        }

        private IEnumerable<Item> Context()
        {
            return new List<Item>
                       {
                           new Item { Id = 1, Name = "One" },
                           new Item { Id = 2, Name = "Two" },
                           new Item { Id = 3, Name = "Three" },
                           new Item { Id = 3, Name = "Three Repeated" },
                           new Item { Id = 4, Name = "Four" },
                           new Item { Id = 5, Name = "Five" },
                           new Item { Id = 6, Name = "Six" },
                           new Item { Id = 7, Name = "Seven" },
                           new Item { Id = 8, Name = null },
                           new Item { Id = 9, Name = null }
                       };
        }

        private class Item
        {
            public int Id { get; set; }
            public string Name { get; set; }
        }

    }
}